Fonts

Struct Fonts 

pub struct Fonts {
    pub fonts: FontsImpl,
    galley_cache: GalleyCache,
}
The collection of fonts used by epaint.

Required in order to paint text. Create one and reuse. Cheap to clone.

Each Fonts comes with a font atlas textures that needs to be used when painting.

If you are using egui, use egui::Context::set_fonts and egui::Context::fonts.

You need to call Self::begin_pass and Self::font_image_delta once every frame.

Fields

fonts: FontsImplgalley_cache: GalleyCache

Implementations

Source

impl Fonts

pub fn new(options: TextOptions, definitions: FontDefinitions) -> Fonts

Create a new Fonts for text layout. This call is expensive, so only create one Fonts and then reuse it.

pub fn begin_pass(&mut self, options: TextOptions)

Call at the start of each frame with the latest known TextOptions.

Call after painting the previous frame, but before using Fonts for the new frame.

This function will react to changes in TextOptions, as well as notice when the font atlas is getting full, and handle that.

pub fn font_image_delta(&mut self) -> Option<ImageDelta>

Call at the end of each frame (before painting) to get the change to the font texture since last call.

pub fn options(&self) -> &TextOptions

pub fn definitions(&self) -> &FontDefinitions

pub fn texture_atlas(&self) -> &TextureAtlas

The font atlas. Pass this to crate::Tessellator.

pub fn image(&self) -> ColorImage

The full font atlas image.

pub fn font_image_size(&self) -> [usize; 2]

Current size of the font image. Pass this to crate::Tessellator.

pub fn has_glyph(&mut self, font_id: &FontId, c: char) -> bool

Can we display this glyph?

pub fn has_glyphs(&mut self, font_id: &FontId, s: &str) -> bool

Can we display all the glyphs in this text?

pub fn num_galleys_in_cache(&self) -> usize

pub fn font_atlas_fill_ratio(&self) -> f32

How full is the font atlas?

This increases as new fonts and/or glyphs are used, but can also decrease in a call to Self::begin_pass.

pub fn with_pixels_per_point(&mut self, pixels_per_point: f32) -> FontsView<'_>

Returns a FontsView with the given pixels_per_point that can be used to do text layout.